#
# spec file for package gh
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define goflags "-buildmode=pie -trimpath -mod=vendor -modcacherw"
Name:           gh
Version:        2.0.0
Release:        bp154.1.31
Summary:        The official CLI for GitHub
License:        MIT
URL:            https://cli.github.com/
Source0:        https://github.com/cli/cli/archive/v%{version}.tar.gz#/gh-%{version}.tar.gz
Source1:        vendor.tar.gz
# Completions
BuildRequires:  fish
# Test requirement
BuildRequires:  git-core
BuildRequires:  zsh
BuildRequires:  golang(API) >= 1.16
Requires:       git

%description
Official CLI client for GitHub written in Go

%package bash-completion
Summary:        Bash Completion for %{name}
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (gh and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (gh and zsh)
BuildArch:      noarch

%description zsh-completion
ZSH command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (gh and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -n cli-%{version} -a 1
# Upstream decided to tweak Makefile for easier cross-compiling. But the tweak
# overrides variables so we need to remove them to pass GOFLAGS.
sed -i 's/GOOS= GOARCH= GOARM= GOFLAGS= CGO_ENABLED=//g' Makefile

%build
GOFLAGS=%{goflags} %make_build GH_VERSION="v%{version}" bin/gh manpages

%install
bin/gh completion -s bash | install -Dm644 /dev/stdin \
       %{buildroot}%{_datadir}/bash-completion/completions/gh
bin/gh completion -s zsh  | install -Dm644 /dev/stdin \
       %{buildroot}%{_datadir}/zsh/site-functions/_gh
bin/gh completion -s fish | install -Dm644 /dev/stdin \
       %{buildroot}%{_datadir}/fish/vendor_completions.d/gh.fish

install -Dm755 bin/gh %{buildroot}%{_bindir}/gh
install -d %{buildroot}%{_mandir}/man1/
cp share/man/man1/* %{buildroot}%{_mandir}/man1

%check
GOFLAGS=%{goflags} make test

%files
%doc README.md
%license LICENSE
%{_bindir}/gh
%{_mandir}/man1/*

%files bash-completion
%{_datadir}/bash-completion/completions/gh

%files zsh-completion
%{_datadir}/zsh/site-functions/_gh

%files fish-completion
%{_datadir}/fish/vendor_completions.d/gh.fish

%changelog
* Thu Sep  2 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 2.0.0
  * Support for command extensions
  * Display label colors in issue list output #4106
  * Add tablerow/tablerender template functions for rendering data as tables #3519
  * Add GH_FORCE_TTY to enable terminal-style output even when redirected #4146
  * Add repo sync command to sync a branch with its upstream state #3813
  * Add pr checkout --branch flag to control the branch name #4005
  * Add release create --discussion-category flag #4003
  * Add config set browser option and GH_BROWSER environment variable #3992
  * Add repo list --topic filter #4136
  * Add PowerShell instructions to completion help #4114
  * Improve accessibility of interactive select menus #4172
  * Improve detection of truecolor terminal capabilities #4106
  * Avoid wrapping issues in powershell.exe #4106
  * Detect missing git and abort early during auth login flow #4109
  * Fix HTTP 502 error printing from GraphQL responses #4154
  * Require Go 1.16+ #4175
  * Remove backwards compatibility with homedir library for config files #4145
* Sat Aug  7 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 1.14.0
  * Improve shell completion #4028
  - Enable --json flag completion with multiple comma-separated fields
  - Add completion for repo create --gitignore flag
  - Add completion for repo create --license flag
  - Switch to Cobra's improved bash completion with descriptions
  - Enable descriptions in PowerShell completion #4085
  - Add completion of -R/--repo flag based on available git remotes #3942
  * Add pr merge --admin flag to allow admins to force-merge a pull request #4071
  * Fix authenticating with GH_ENTERPRISE_TOKEN and GH_HOST environment variables #4019
  * Fix labels display in issue list output #4079
  * Fix printing certain GraphQL errors #4087
* Wed Jul 28 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 1.13.1
  * Release fixes pre-built binaries, changes aren't applicable to this package
- Changes from 1.13.0
  * issue/pr view: output label names in their own color #3912
  * Add gh browse --no-browser to only print the URL #3943
  * repo create: respect privacy setting when using license/gitignore templates #3972
  * repo create: respect repository description when creating from template repository #3972
  * repo create --confirm: avoid license/gitignore template prompt #3995
  * pr merge --auto: merge immediately if the PR is already mergeable #3706
  * pr merge: suggest using --auto when merging is blocked #3706
  * Allow using cursor keys in interactive text inputs #3980
  * gh run watch --exit-status: correct exit status for completed runs #3982
  * Skip auto-migrate of config files when GH_CONFIG_DIR is set #4017
  * alias set: add note about double-quoting arguments for Command Prompt users #4013
  * Clean up GH_CONFIG_DIR docs #4020
- Changes from 1.12.1
  * Fix bug where branchProtectionRule doesn't exist in enterprise 2.22 #3922
  * Fix repo create in org with license/ignore #3924
- Changes from 1.12.0
  * Added gh browse command
  * Add .gitignore and LICENSE when creating repositories from scratch
  * A new config value http_unix_socket can be configured to a local path to push all traffic over a socket
  * Print help even if logged out #3850
  * Add shell completion for the --state flag #3877
  * Allow explicitly empty body in issue/pr create #3787
  * Increase GH_PAGER precedence #3789
  * Fix showing Checks information in pr status #3804
  * Update "Accept" header for github.com requests #3803
  * Fix setting environment secrets #3832
  * Fix gh run download fails on large artifacts due to uint32 limitation #3890
  * repo fork: check that --org is not the empty string #3807
  * Document installing via Conda package manager #3792
  * Fix description for gh secret set --env option #3784
  * Add a long command description for secrets remove #3786
  * Update documentation for gist create command with default of secret #3871
  * fork tests cleanup #3809
  * Remove unused method from httpmock package #3834
  * Factory cleanup #3841
  * Improvements to build script on Windows #3846
  * Ensure that tests for command factory never read from user's config #3856
* Wed Jun 23 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.11.0:
  * Add support for environment secrets #3270 #3769 #3774
  * run list: add "age" column and columns headers in output #3575
  * Add support for XDG Base Directory specification #3671 #3768 #3717
  * Additionally, the default configuration location on Windows is now changed from ~/.config/gh/ to %%AppData%%.
  * Include number alongside the title in issue/pr view #3741
* Sat May 22 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.10.3:
  * Fix gh pr merge with GitHub Enterprise Server < 3.0 #3688
  * Speed up measuring display width of text #3668
  * Simplify Debian/Ubuntu installation docs #3672
- Changes from 1.10.2:
  * Fix creating Windows directory for gh config #3666
* Wed May 19 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.10.1:
  * Fix pr checkout for cross-repository pull requests #3663
* Wed May 19 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.10.0:
  - Improvements to JSON exporting
  * Add gh repo list/view --json support #3627
  * Add gh release view --json support #3656
  * Fixes numerous issues with gh pr list/view --json support #3547
  - fetching closed field
  - fetching date fields like createdAt or mergedAt
  - fetching files field
  * Fix exporting milestone field for issues and PRs #3529
  * Add commits field to JSON export for PRs #3547
  * Show more than 100 comments in gh issue view --json comments #3547
  * Add shell completion for valid --json flag values #3628
  - New Features
  * Add gh repo fork --org option #3611
  * Allow passinggh alias set value via standard input #3490
  * Prompt for value in gh secret set #3499
  * Update gh api placeholder syntax to {owner}, {repo} to match
    GitHub API documentation #3536
  * Extend our package repository to support Ubuntu Hirsute and
    Kali linux #3398
  - Fixes
  * Speedup across most gh pr commands #3547
  * Fix gh pr operations from GitHub Actions when a PR was added
    as a card to an org project #3547
  * Allow deleting local git branch in gh pr close #3547
  * Fix showing more than 100 checks in gh pr checks #3547
  * Fix viewing and editing draft releases with GitHub Actions token #3656
  * Fix Windows path in gh auth status output #3491
  * Ignore HTTP 404 error for annotations in gh run watch #3517
  * Handle Incorrect function exception for MinTTY users
    (typically in Git Bash) by suggesting switching to Windows Terminal #3537
  * Query fewer fields to determine issue status #3525
  * Warn about empty contents on gh gist create #3578
  * Fix "null" display in colored JSON output #3626
  * Fix some docs formatting for the web #3648
* Tue Apr 20 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.9.2:
  - Actions Fixes
  * Fix Actions use int64 explicitly in Actions support #3432
  * Fix requesting REST sub-resources on GHE #3461
  * Fix run view --log when steps have slashes #3445
  * Include magic repo resolution magic for gh workflow and gh run #3468
  - Other Fixes
  * Fix issue create --web #3472
  * Fix detecting PR status when passing branch as arg #3351
  * Bump AlecAivazis/survey to fix bug with unicode input #3439
  - Development / Docs
  * Increase linter timeout from 1min to 3min #3462
  * Remove unused embedded struct #3402
  * Add note on supported value types in raw-fields #3400
  * linuxbrew details added in linux installation docs. #3465
  * Add Funtoo Linux install instructions #3438
  * Add Debian install variant without add-apt-repository #3419
* Mon Apr 19 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.9.1:
  * Create cache dir
  * Fix whitespace formatting of `issue/pr view` help text
  * Disallow unsupported values for `--json` flag
  * Fix `pr view` tests broken by `createdAt` → `submittedAt` switch
  * Fix assigning null Exporter
  * Tests for GraphQL query builder and JSON exporter
  * Add `gh help formatting` topic & link to it from commands with JSON output
  * Placeholder consistency
  * Minor usage improvements
  * Bump run list limit
  * Annotation fixes
  * Unhide actions commands
  * Incorporate wording feedback
  * Fix small bug with startup_failure conclusion
  * Add note about current branch detection
- Prevent Makefile from overriding variables
- Enable tests
* Tue Apr 13 2021 Martin Pluskal <mpluskal@suse.com>
- Supplement bash-completion instead of bash
* Mon Apr 12 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.8.1:
  * Fix pr status/checks crash with unrecognized statuse from
    the server(#3336)
  * Fix repo fork --clone not cloning an existing fork locally
    when running non-interactively(#3334)
  * Fix commands not respecting default hostname from GH_HOST(#3347)
- Create subpackages for completions
* Sun Mar  7 2021 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * see https://github.com/cli/cli/releases/tag/v1.7.0
  * https://github.com/cli/cli/releases/tag/v1.6.0
  * https://github.com/cli/cli/releases/tag/v1.5.0
* Tue Dec 15 2020 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 1.4.0
  * Add ability to view issue and pull request comment threads
  * Add management of GitHub Actions secrets
  * Set up git credentials when logging in to GitHub CLI
  * Add make install and make uninstall for POSIX systems when building from source
  * pr merge: attempt the merge even if mergeability status could not be determined
  * repo clone: enable cloning repository wikis
  * Recognize Include directives when parsing ssh config files
  * Display the new release notice only once per 24 hours
* Thu Dec 10 2020 Emily Roberts <nopeinomicon@posteo.net>
- Fix app not showing the correct version
- Install readme and license files
* Thu Dec 10 2020 Martin Pluskal <mpluskal@suse.com>
- Build and install manpages as well
* Wed Dec  9 2020 Emily Roberts <nopeinomicon@posteo.net>
- Use source specified at Source0 URL
- Switch from tar_scm to download_files for obtaining source archive
* Tue Dec  8 2020 Emily Roberts <nopeinomicon@posteo.net>
- Simplify BuildRequires
* Mon Dec  7 2020 Emily Roberts <nopeinomicon@posteo.net>
- Revert back to tar_scm service for submission to openSUSE:Factory
* Mon Dec  7 2020 nopeinomicon@posteo.net
- Update to version 1.3.1:
  * Allow interactive `pr create` even if we failed to look up commits
  * AskStubber now throws a more descriptive error when stubs do not match
  * Make MetadataSurvey testable by accepting an interface
  * Ensure efficient resolving of `issue/pr create` metadata to GraphQL IDs
  * don't reset previously added metadata
  * Prompt: avoid resetting PR/issue metadata if no option is selected
  * Fix "Continue in browser" for `pr create` coming from forks
  * Fix browser URL test on Windows
  * Fix respecting chosen action in interactive `issue create`
  * Properly check env auth tokens in CheckAuth
  * Delete an error message that is not useful (and had a typo)
  * Document that reviewers can be teams (#2465)
  * Bump AlecAivazis/survey
  * Sort latest PRs first when looking up PRs for a branch
* Wed Dec  2 2020 Emily Roberts <nopeinomicon@posteo.net>
- Reinstated and fixed obs_scm service for source control
- Fixed build for openSUSE Leap
* Mon Nov 30 2020 Emily Roberts <nopeinomicon@posteo.net>
- Return to tar_scm due to breakages with obs_scm service
* Wed Nov 25 2020 nopeinomicon@posteo.net
- Switch from tar_scm to obs_scm service
- Update to version 1.3.0:
  * Warn termux users with older Android versions (#2467)
  * no shorthand for --recover
  * switch to recover instead of resubmit
  * linter appeasement
  * use TempFile though the testing is gross
  * fix dumb test
  * preserve and restore issue/pr input on failure
  * add IOStreams.ReadUserFile
  * spelling: unmatched
  * spelling: template
  * spelling: settings
  * spelling: response
  * spelling: nonexistent
  * spelling: error
  * spelling: dunno
  * spelling: dismissed
  * spelling: deprecated
  * spelling: chestnuts
  * spelling: beginning
  * match parent repo protocol when forking (#2434)
  * respect GH_HOST when resolving remotes (#2301)
  * Add "reference" help topic (#2223)
  * Implement --web for gh pr checks (#2146)
  * Downgrade survey to v2.1.1
  * fix missing import
  * Support for --web when using gist create (#2263)
  * Add a command to delete a gist (#2265)
  * fix survey invocation
  * Fix USAGE help for some commands
  * add empty line between functions
  * Generate correct URL when branch option is passed in
  * add Draft to issue state
  * use NewIssueState
  * get everything working
  * stop using Defaults struct
  * stop using string pointer
  * WIP works, probably some title/body input edge cases
  * use named output param
  * Fix typos
  * Empty auth token env variables are equal to being unset
  * cleanup
  * Add support for GH_TOKEN and GH_ENTERPRISE_TOKEN
  * Consistently print commands in DEBUG mode
* Sun Nov 15 2020 Emily Roberts <nopeinomicon@posteo.net>
- Clean up .spec file
* Thu Nov 12 2020 nopeinomicon@posteo.net
- Update to version 1.2.1:
  * Fix git executable name for Windows in tests
  * Improve error message when git isn't found
  * Omit the full path of a command in DEBUG mode
  * Ensure that only PATH is searched when shelling out to external commands
  * Bump golang.org/x/text
  * Bump golang.org/x/crypto
  * Bump shurcooL/githubv4
  * Bump muesli/termenv
  * Bump mattn/go-colorable
  * Bump AlecAivazis/survey
  * Fix `truncateLabels` for empty values
  * Ensure parentheses are preserved after truncating labels in table view
  * Render links as absolute URLs in `repo view` (#2363)
  * Add Gentoo instructions to install the package (#2389)
  * Show MousetrapHelpText when double-clicking gh.exe
  * Small cleanup
  * Make markdown:generate annotation a markdown generation override for hidden commands
  * Generate markdown for help topics
  * Refactor help topics to include short message
  * Extract repeated code to util function
  * improve error message
  * Refactor regexp writer
  * Add multiple writes test
  * Use custom scanLines function for RegexWriter
  * Fix up regex to escape dot in URL
  * Address PR comments
  * Filter out unwanted stderr output during git push commands
  * new packages for get and set subcommands
  * Export type ConfigOption and group InvalidValueError code
  * Refactor config command
  * Cleanup duplicate config options
  * move cobra mutation and document it
  * Update install_linux.md
  * more iostreams passing
  * try passing iostreams around instead of writer+colorscheme
  * use shared color function
  * favor SuccessIcon
  * Use slice and make both status lines the size of the terminal width.
  * Use terminal width for the status line
  * port entirely to ColorScheme
  * added extra notes
  * Better tests for clone argument parsing
  * added Snap installation docs
  * Simplify checks test
  * add message on `pr checks` returns no CI with non-empty PR
  * Fetch all issue labels
  * Update triage.md
  * link to aliases
  * :nail_care: code style
  * :nail_care: simplify `sortPullRequestsByState`
  * PullRequestForBranch: fix outdated error message
  * Allow PullRequestForBranch to search in closed pull requests
  * Mention winget as an install option in README (#2272)
  * Small releasing docs cleanup
  * Update triage.md
  * Clean up and refactor unused doc generation code
  * Remove SEE ALSO from markdown docs generation
  * Remove Cobra autogenerated string from docs generation
  * Internalize doc generation from Cobra
  * Print friendly error when "gh repo clone" is missing required argument
  * removed runtime compare for windows The MousttrapHelpText will only be validated in cobra when running on windows.
  * run gh commands from explorer.exe
* Tue Nov 10 2020 Emily Roberts <nopeinomicon@posteo.net>
- Initial package version
